summaryrefslogtreecommitdiffstats
path: root/src/datavis3d/engine/q3dscatter.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/datavis3d/engine/q3dscatter.h')
-rw-r--r--src/datavis3d/engine/q3dscatter.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/datavis3d/engine/q3dscatter.h b/src/datavis3d/engine/q3dscatter.h
index 13c50415..f85a5c5f 100644
--- a/src/datavis3d/engine/q3dscatter.h
+++ b/src/datavis3d/engine/q3dscatter.h
@@ -104,10 +104,10 @@ public:
void setBarColor(QColor baseColor, QColor heightColor, QColor depthColor,
bool uniform = true);
// Set tick count and step. Note; tickCount * step should be the maximum possible value of data
// set. Minimum is the absolute minimum possible value a bar can have. This is especially
// important to set if values can be negative.
- void setTickCount(int tickCount, qreal step, qreal minimum = 0.0f);
+ void setSegmentCount(int segmentCount, qreal step, qreal minimum = 0.0f);
// override bar type with own mesh
void setMeshFileName(const QString &objFileName);
@@ -104,10 +104,10 @@ public:
void setBarColor(QColor baseColor, QColor heightColor, QColor depthColor,
bool uniform = true);
- // Set tick count and step. Note; tickCount * step should be the maximum possible value of data
+ // Set segment count and step. Note; segmentCount * step should be the maximum possible value of data
// set. Minimum is the absolute minimum possible value a bar can have. This is especially
// important to set if values can be negative.